@@ -4,11 +4,13 @@ from enum import Enum, auto
 from uuid import uuid4
 
 from common import app_settings
+from common.app_settings import domain
 from common.email_messages import (
     emailChangeNotificationEmail,
     emailChangeVerificationEmail,
     emailChangeDuplicateNotificationEmail,
     emailVerificationNeededEmail,
+    parentsEmailVerificationNeededEmail,
 )
 from common.models import EmailVerification, Teacher, Student
 from django.contrib.auth.models import User
@@ -18,13 +20,10 @@ from django.template import loader
 from django.utils import timezone
 from requests import post, get, put, delete
 from requests.exceptions import RequestException
-from common.app_settings import domain
 
 NOTIFICATION_EMAIL = "Code For Life Notification <" + app_settings.EMAIL_ADDRESS + ">"
 VERIFICATION_EMAIL = "Code For Life Verification <" + app_settings.EMAIL_ADDRESS + ">"
-PASSWORD_RESET_EMAIL = (
-    "Code For Life Password Reset <" + app_settings.EMAIL_ADDRESS + ">"
-)
+PASSWORD_RESET_EMAIL = "Code For Life Password Reset <" + app_settings.EMAIL_ADDRESS + ">"
 INVITE_FROM = "Code For Life Invitation <" + app_settings.EMAIL_ADDRESS + ">"
 
 
@@ -51,11 +50,7 @@ def send_email(
     plaintext = loader.get_template(plaintext_template)
     html = loader.get_template(html_template)
     plaintext_email_context = {"content": text_content}
-    html_email_context = {
-        "content": text_content,
-        "title": title,
-        "url_prefix": domain(),
-    }
+    html_email_context = {"content": text_content, "title": title, "url_prefix": domain()}
 
     # render templates
     plaintext_body = plaintext.render(plaintext_email_context)
@@ -78,7 +73,7 @@ def generate_token(user, email="", preverified=False):
     )
 
 
-def send_verification_email(request, user, new_email=None):
+def send_verification_email(request, user, new_email=None, age=None):
     """Send an email prompting the user to verify their email address."""
 
     if not new_email:  # verifying first email address
@@ -86,35 +81,21 @@ def send_verification_email(request, user, new_email=None):
 
         verification = generate_token(user)
 
-        message = emailVerificationNeededEmail(request, verification.token)
-        send_email(
-            VERIFICATION_EMAIL,
-            [user.email],
-            message["subject"],
-            message["message"],
-            message["subject"],
-        )
+        if age is not None and age < 13:
+            message = parentsEmailVerificationNeededEmail(request, user, verification.token)
+            send_email(VERIFICATION_EMAIL, [user.email], message["subject"], message["message"], message["subject"])
+        else:
+            message = emailVerificationNeededEmail(request, verification.token)
+            send_email(VERIFICATION_EMAIL, [user.email], message["subject"], message["message"], message["subject"])
 
     else:  # verifying change of email address.
         verification = generate_token(user, new_email)
 
         message = emailChangeVerificationEmail(request, verification.token)
-        send_email(
-            VERIFICATION_EMAIL,
-            [user.email],
-            message["subject"],
-            message["message"],
-            message["subject"],
-        )
+        send_email(VERIFICATION_EMAIL, [user.email], message["subject"], message["message"], message["subject"])
 
         message = emailChangeNotificationEmail(request, new_email)
-        send_email(
-            VERIFICATION_EMAIL,
-            [user.email],
-            message["subject"],
-            message["message"],
-            message["subject"],
-        )
+        send_email(VERIFICATION_EMAIL, [user.email], message["subject"], message["message"], message["subject"])
 
 
 def is_verified(user):
@@ -123,9 +104,7 @@ def is_verified(user):
     return len(verifications) != 0
 
 
-def add_to_dotmailer(
-    first_name: str, last_name: str, email: str, user_type: DotmailerUserType
-):
+def add_to_dotmailer(first_name: str, last_name: str, email: str, user_type: DotmailerUserType):
     try:
         create_contact(first_name, last_name, email)
         add_contact_to_address_book(first_name, last_name, email, user_type)
@@ -146,29 +125,14 @@ def create_contact(first_name, last_name, email):
                 {"key": "FULLNAME", "value": f"{first_name} {last_name}"},
             ],
         },
-        "consentFields": [
-            {
-                "fields": [
-                    {
-                        "key": "DATETIMECONSENTED",
-                        "value": datetime.datetime.now().__str__(),
-                    },
-                ]
-            }
-        ],
+        "consentFields": [{"fields": [{"key": "DATETIMECONSENTED", "value": datetime.datetime.now().__str__()}]}],
         "preferences": app_settings.DOTMAILER_DEFAULT_PREFERENCES,
     }
 
-    post(
-        url,
-        json=body,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    post(url, json=body, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
 
-def add_contact_to_address_book(
-    first_name: str, last_name: str, email: str, user_type: DotmailerUserType
-):
+def add_contact_to_address_book(first_name: str, last_name: str, email: str, user_type: DotmailerUserType):
     main_address_book_url = app_settings.DOTMAILER_MAIN_ADDRESS_BOOK_URL
 
     body = {
@@ -182,11 +146,7 @@ def add_contact_to_address_book(
         ],
     }
 
-    post(
-        main_address_book_url,
-        json=body,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    post(main_address_book_url, json=body, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
     specific_address_book_url = app_settings.DOTMAILER_NO_ACCOUNT_ADDRESS_BOOK_URL
 
@@ -195,11 +155,7 @@ def add_contact_to_address_book(
     elif user_type == DotmailerUserType.STUDENT:
         specific_address_book_url = app_settings.DOTMAILER_STUDENT_ADDRESS_BOOK_URL
 
-    post(
-        specific_address_book_url,
-        json=body,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    post(specific_address_book_url, json=body, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
 
 def delete_contact(email: str):
@@ -207,13 +163,8 @@ def delete_contact(email: str):
         user = get_dotmailer_user_by_email(email)
         user_id = user.get("id")
         if user_id:
-            url = app_settings.DOTMAILER_DELETE_USER_BY_ID_URL.replace(
-                "ID", str(user_id)
-            )
-            delete(
-                url,
-                auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-            )
+            url = app_settings.DOTMAILER_DELETE_USER_BY_ID_URL.replace("ID", str(user_id))
+            delete(url, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
     except RequestException:
         return HttpResponse(status=404)
 
@@ -221,10 +172,7 @@ def delete_contact(email: str):
 def get_dotmailer_user_by_email(email):
     url = app_settings.DOTMAILER_GET_USER_BY_EMAIL_URL.replace("EMAIL", email)
 
-    response = get(
-        url,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    response = get(url, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
     return json.loads(response.content)
 
@@ -232,9 +180,7 @@ def get_dotmailer_user_by_email(email):
 def add_consent_record_to_dotmailer_user(user):
     consent_date_time = datetime.datetime.now().__str__()
 
-    url = app_settings.DOTMAILER_PUT_CONSENT_DATA_URL.replace(
-        "USER_ID", str(user["id"])
-    )
+    url = app_settings.DOTMAILER_PUT_CONSENT_DATA_URL.replace("USER_ID", str(user["id"]))
     body = {
         "contact": {
             "email": user["email"],
@@ -242,35 +188,18 @@ def add_consent_record_to_dotmailer_user(user):
             "emailType": user["emailType"],
             "dataFields": user["dataFields"],
         },
-        "consentFields": [
-            {
-                "fields": [
-                    {"key": "DATETIMECONSENTED", "value": consent_date_time},
-                ]
-            }
-        ],
+        "consentFields": [{"fields": [{"key": "DATETIMECONSENTED", "value": consent_date_time}]}],
     }
 
-    put(
-        url,
-        json=body,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    put(url, json=body, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
 
 def send_dotmailer_consent_confirmation_email_to_user(user):
     url = app_settings.DOTMAILER_SEND_CAMPAIGN_URL
     campaign_id = app_settings.DOTMAILER_THANKS_FOR_STAYING_CAMPAIGN_ID
-    body = {
-        "campaignID": campaign_id,
-        "contactIds": [str(user["id"])],
-    }
+    body = {"campaignID": campaign_id, "contactIds": [str(user["id"])]}
 
-    post(
-        url,
-        json=body,
-        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
-    )
+    post(url, json=body, auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD))
 
 
 def update_indy_email(user, request, data):
@@ -293,10 +222,7 @@ def update_indy_email(user, request, data):
         else:
             # new email to set and verify
             send_verification_email(request, user, new_email)
-    return (
-        changing_email,
-        new_email,
-    )
+    return changing_email, new_email
 
 
 def update_email(user: Teacher or Student, request, data):
